cmoncrawl.middleware.stompware
==============================

.. automodule:: cmoncrawl.middleware.stompware

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autoclass:: StompAggregator
      :members:

   .. autoclass:: StompProcessor
      :members:
   
   

   
   
   



